package logic

import (
	"errors"
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
	"gorm.io/gorm"
)

type SaveApiLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewSaveApiLogic(ctx context.Context, svcCtx *svc.ServiceContext) *SaveApiLogic {
	return &SaveApiLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *SaveApiLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *SaveApiLogic) SaveApi(req *types.SaveApiReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null
	var err1 error
	if req.Id > 0 {
		resOne, err := l.svcCtx.AllModels.LdapApis.FindOneById(l.ctx, req.Id)
		if err != nil {
			if errors.Is(err, gorm.ErrRecordNotFound) {
				basic.CodeServiceErr.Message = "记录不存在"
			} else {
				basic.CodeServiceErr.Message = "系统出错"
			}
			return resp.SetStatus(basic.CodeServiceErr)
		}
		var updateMap = make(map[string]interface{})
		if req.Method != "" {
			updateMap["method"] = req.Method
		}
		if req.Path != "" {
			updateMap["path"] = req.Path
		}
		if req.Category != "" {
			updateMap["category"] = req.Category
		}
		if req.Remark != "" {
			updateMap["remark"] = req.Remark
		}
		err1 = l.svcCtx.AllModels.LdapApis.UpdateOne(l.ctx, resOne, updateMap)
	} else {
		err1 = l.svcCtx.AllModels.LdapApis.InsertOne(l.ctx, gmodel.LdapApis{
			Method:   &req.Method,
			Path:     &req.Path,
			Category: &req.Category,
			Remark:   &req.Remark,
			//Creator:  &req.Creator,
		})
	}
	if err1 != nil {
		basic.CodeServiceErr.Message = "系统出错"
		return resp.SetStatus(basic.CodeServiceErr)
	}
	return resp.SetStatus(basic.CodeOK)
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *SaveApiLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
